@@ -20,67 +20,33 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-lambda-s3`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.lambdas3`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS Lambda function connected to an Amazon S3 bucket.
 
-Here is a minimal deployable pattern definition :
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
 import { LambdaToS3 } from '@aws-solutions-constructs/aws-lambda-s3';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
 
 new LambdaToS3(this, 'LambdaToS3Pattern', {
     lambdaFunctionProps: {
         runtime: lambda.Runtime.NODEJS_14_X,
         handler: 'index.handler',
-        code: lambda.Code.fromAsset(`lambda`)
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`)
     }
 });
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_lambda_s3 import LambdaToS3
-from aws_cdk import (
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-LambdaToS3(self, 'LambdaToS3Pattern',
-        lambda_function_props=_lambda.FunctionProps(
-            code=_lambda.Code.from_asset('lambda'),
-            runtime=_lambda.Runtime.PYTHON_3_9,
-            handler='index.handler'
-        )
-        )
+```text
+new LambdaToS3(scope: Construct, id: string, props: LambdaToS3Props);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.lambdas3.*;
-
-new LambdaToS3(this, "LambdaToS3Pattern", new LambdaToS3Props.Builder()
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_14_X)
-                .code(Code.fromAsset("lambda"))
-                .handler("index.handler")
-                .build())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`LambdaToS3Props`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -94,7 +60,7 @@ new LambdaToS3(this, "LambdaToS3Pattern", new LambdaToS3Props.Builder()
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon SQS. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
 |vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
-|bucketEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the name of the bucket. Default: S3_BUCKET_NAME |
+|bucketEnvironmentVariableName?|`string`|Optional name for the S3 bucket environment variable set for the Lambda function.|
 |loggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Logging Bucket.|
 |logS3AccessLogs?| boolean|Whether to turn on Access Logging for the S3 bucket. Creates an S3 bucket with associated storage costs for the logs. Enabling Access Logging is a best practice. default - true|
 
@@ -151,18 +117,16 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class LambdaToS3(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-s3.LambdaToS3",
 ):
@@ -172,25 +136,25 @@ class LambdaToS3(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         bucket_environment_variable_name: typing.Optional[builtins.str] = None,
         bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param bucket_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the bucket. Default: - S3_BUCKET_NAME
+        :param bucket_environment_variable_name: Optional name for the S3 bucket environment variable set for the Lambda function. Default: - None
         :param bucket_permissions: Optional bucket permissions to grant to the Lambda function. One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -206,10 +170,6 @@ class LambdaToS3(
         :since: 0.8.0
         :summary: Constructs a new instance of the LambdaToS3 class.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(LambdaToS3.__init__)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToS3Props(
             bucket_environment_variable_name=bucket_environment_variable_name,
             bucket_permissions=bucket_permissions,
@@ -226,27 +186,27 @@ class LambdaToS3(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
@@ -275,18 +235,18 @@ class LambdaToS3Props:
         *,
         bucket_environment_variable_name: typing.Optional[builtins.str] = None,
         bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
-        :param bucket_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the bucket. Default: - S3_BUCKET_NAME
+        :param bucket_environment_variable_name: Optional name for the S3 bucket environment variable set for the Lambda function. Default: - None
         :param bucket_permissions: Optional bucket permissions to grant to the Lambda function. One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
         :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -301,26 +261,13 @@ class LambdaToS3Props:
         :summary: The properties for the LambdaToS3 class.
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = BucketProps(**bucket_props)
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = BucketProps(**logging_bucket_props)
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
-        if __debug__:
-            type_hints = typing.get_type_hints(LambdaToS3Props.__init__)
-            check_type(argname="argument bucket_environment_variable_name", value=bucket_environment_variable_name, expected_type=type_hints["bucket_environment_variable_name"])
-            check_type(argname="argument bucket_permissions", value=bucket_permissions, expected_type=type_hints["bucket_permissions"])
-            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
-            check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
-            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
-            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
-            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
-            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
-            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
-            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
-            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_environment_variable_name is not None:
             self._values["bucket_environment_variable_name"] = bucket_environment_variable_name
@@ -347,9 +294,9 @@ class LambdaToS3Props:
 
     @builtins.property
     def bucket_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the Lambda function environment variable set to the name of the bucket.
+        '''Optional name for the S3 bucket environment variable set for the Lambda function.
 
-        :default: - S3_BUCKET_NAME
+        :default: - None
         '''
         result = self._values.get("bucket_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
